#!/usr/bin/env python
"""SPDX-FileCopyrightText: (c) 2024 by mundialis GmbH & Co. KG.

SPDX-License-Identifier: GPL-3.0-or-later

Plugin setup file
"""

from setuptools import setup

if __name__ == "__main__":
    setup()
